#
# spec file for package libnetfilter_conntrack
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libnetfilter_conntrack
%define lname	libnetfilter_conntrack3
Version:        1.0.9
Release:        1.9
Summary:        Userspace library for the in-kernel connection tracking state table
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Security
URL:            https://netfilter.org/projects/libnetfilter_conntrack/

#Git-Clone:	https://git.netfilter.org/libnetfilter_conntrack/
Source:         https://netfilter.org/projects/libnetfilter_conntrack/files/%name-%version.tar.bz2
Source2:        https://netfilter.org/projects/libnetfilter_conntrack/files/%name-%version.tar.bz2.sig
Source3:        baselibs.conf
Source4:        %name.keyring
BuildRequires:  pkgconfig >= 0.21
BuildRequires:  pkgconfig(libmnl) >= 1.0.3
BuildRequires:  pkgconfig(libnfnetlink) >= 1.0.0

%description
libnetfilter_conntrack is a userspace library providing a programming
interface (API) to the in-kernel connection tracking state table. The
library libnetfilter_conntrack has been previously known as
libnfnetlink_conntrack and libctnetlink. This library is currently
used by conntrack-tools among many other applications.

%package -n %lname
Summary:        Userspace library for the in-kernel connection tracking state table
Group:          System/Libraries

%description -n %lname
libnetfilter_conntrack is a userspace library providing a programming
interface (API) to the in-kernel connection tracking state table. The
library libnetfilter_conntrack has been previously known as
libnfnetlink_conntrack and libctnetlink. This library is currently
used by conntrack-tools among many other applications.

%package devel
Summary:        Userspace library for the in-kernel connection tracking state table
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
libnetfilter_conntrack is a userspace library providing a programming
interface (API) to the in-kernel connection tracking state table. The
library libnetfilter_conntrack has been previously known as
libnfnetlink_conntrack and libctnetlink. This library is currently
used by conntrack-tools among many other applications.

%prep
%autosetup -p1

%build
# includedir intentional, cf. bugzilla.opensuse.org/795968
%configure --disable-static --includedir="%_includedir/%name"
make %{?_smp_mflags}

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%_libdir/libnetfilter_conntrack.so.3*

%files devel
%_includedir/%name/
%_libdir/libnetfilter_conntrack.so
%_libdir/pkgconfig/libnetfilter_conntrack.pc

%changelog
* Mon Feb 14 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.0.9
  * This release comes with the new nfct_nlmsg_build_filter()
    function that allows to add metadata for kernel-side
    filtering of conntrack entries during conntrack table dump.
  * The nfct_query() API supports the new NFCT_Q_FLUSH_FILTER
    argument, it allows to flush only IPv6 or IPv4 entries from
    the connection tracking table.
* Wed Oct 14 2020 Jan Engelhardt <jengelh@inai.de>
- Modernize specfile constructs.
* Wed Apr  1 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.0.8
  * conntrack: support for IPS_OFFLOAD
* Tue May  1 2018 jengelh@inai.de
- Update to new upstream release 1.0.7
  * new synproxy support
  * don't crash on NULL labelmap
  * expose a copy of nf_conntrack_common.h
* Mon Aug 22 2016 jengelh@inai.de
- Update to new upstream release 1.0.6
  * add support for IPv6 NAT
  * conntrack: add zone attribute to tuple
* Wed Sep  9 2015 jengelh@inai.de
- Update to new upstream release 1.0.5
  * conntrack: add mark event filter
  * conntrack: compare: relax MARK/ZONE attribute comparison
* Mon Dec  8 2014 jengelh@inai.de
- Drop %%version from subincludedir, it tends to break recompiles of
  already-built trees on library updates.
* Tue Sep 23 2014 jengelh@inai.de
- Drop gpg-offline build-time requirement; this is now handled by
  the local source validator
* Wed Aug  7 2013 jengelh@inai.de
- Update to new upstream release 1.0.4
  * This release includes connlabel support, one memleak fix and
  fixes in the comparison API.
* Mon Mar  4 2013 jengelh@inai.de
- Update to new upstream release 1.0.3
  * Treat the ATTR_HELPER_INFO attribute as the variable-length type
  that it actually is.
  * Fix a use after free when nfct_clone was used with certain
  attribute data types.
* Wed Nov 28 2012 sbrabec@suse.cz
- Verify GPG signature
* Mon Oct  8 2012 jengelh@inai.de
- Update to new upstream release 1.0.2
  * This release provides new interfaces to interact with libmnl,
  and also has several fixes.
* Sat May 19 2012 jengelh@inai.de
- Update to new upstream release 1.0.1
  * add NAT, expectfn and class support
  * conntrack: add new ATTR_GRP_[ORIG|REPL]_ADDR_[SRC|DST] attributes
* Wed Jan  4 2012 jengelh@medozas.de
- Update to new upstream release 1.0.0
  * build and compilation updates
  * expect: fix missing parsing of master tuple
  * expect: nfexp_snprintf prints expectation timeout if present
  * expect: nfexp_snprintf displays mask and master tuple information
  * expect: add nfexp_send()
  * expect: support CTA_EXPECT_HELP_NAME
  * src: clarify licensing terms of library (GPLv2+)
  * conntrack: fix size of CTA_PROTOINFO_TCP_FLAGS_ORIGINAL in ARM
  * conntrack: fix set operation for master IPv6 src and dst
  * expect: add nfexp_cmp
* Thu Dec 29 2011 jengelh@medozas.de
- SPDX format for License: tag
- Use separate include directory to catch compile errors
* Thu Feb 24 2011 jengelh@medozas.de
- new upstream release 0.9.1
  * add support for CTA_SECCTX and CTA_EXPECT_ZONE
  * allow to use nfct handler for conntrack and expectations at
  the same time
  * conntrack: add timestamp support
* Wed Sep  8 2010 jengelh@medozas.de
- new upstream release 0.9.0
  * ct: fix regression with helpers for Linux kernel >= 2.6.34
  * ct: fix EINVAL if not TCP attributes are set for Linux
  kernel <= 2.6.25
* Thu Jul 15 2010 jengelh@medozas.de
- new upstream release 0.0.102
  * support for conntrack zones
  * support for TCP window scale factor
* Tue Feb 23 2010 jengelh@medozas.de
- new upstream release: 0.0.101
- add baselibs.conf
- use %%_smp_mflags
- remove unnecessary PreReq: glibc
- secure the *.la delete call
- wrap description at col 70
* Sun Sep 20 2009 bitshuffler #suse@irc.freenode.org
- Updated to 0.0.100
